@@ -4,6 +4,7 @@ from typing import List
 
 import openpyxl
 import six
+import math
 from openpyxl.chart.shapes import GraphicalProperties
 from openpyxl.drawing.image import Image
 from openpyxl.drawing.spreadsheet_drawing import AnchorMarker
@@ -252,7 +253,7 @@ def worksheet_to_data(ws, locale=None, fs=None, default_cell_border="none"):
     return {"rows": data_list, "cols": col_list, "images": images_to_data(ws)}
 
 
-def render_table(data, append_headers, append_lineno, start, end):
+def render_table(data, append_headers, append_lineno):
     html = [
         "<table  "
         'style="border-collapse: collapse" '
@@ -275,7 +276,6 @@ def render_table(data, append_headers, append_lineno, start, end):
     append_headers(data, html)
 
     for i, row in enumerate(data["rows"]):
-        if i == end: break
         trow = [('<tr id="{}">').format(i)]
         append_lineno(trow, i)
         for cell in row:
@@ -312,6 +312,8 @@ def render_table(data, append_headers, append_lineno, start, end):
 
 
 def render_data_to_html(data, append_headers, append_lineno):
+    length = 22;
+    data_break = math.ceil(data["rows"].len() / length)
     html = """
     <!DOCTYPE html>
     <html lang="en">
@@ -338,7 +340,10 @@ def render_data_to_html(data, append_headers, append_lineno):
     </body>
     </html>
     """
-    return html % render_table(data, append_headers, append_lineno, 0, 22)
+    render_paged_table = []
+    for i in data_break:
+        render_paged_table.append(render_table(data["rows"][i*length:(i+1)*length], append_headers, append_lineno))
+    return html % render_paged_table
 
 
 def get_sheet(wb, sheet):
